@@ -21,6 +21,9 @@ class fe25519():
     d2 = None
     sqrtm1 = None
     invsqrtamd = None
+    onemsqd = None
+    sqdmone = None
+    sqrtadm1 = None
     curve25519_A = None
 
     @staticmethod
@@ -536,6 +539,15 @@ fe25519.sqrtm1 = fe25519([
 fe25519.invsqrtamd = fe25519([
     278908739862762, 821645201101625, 8113234426968, 1777959178193151, 2118520810568447
 ])
+fe25519.onemsqd = fe25519([
+    1136626929484150, 1998550399581263, 496427632559748, 118527312129759, 45110755273534
+])
+fe25519.sqdmone = fe25519([
+    1507062230895904, 1572317787530805, 683053064812840, 317374165784489, 1572899562415810
+])
+fe25519.sqrtadm1 = fe25519([
+    2241493124984347, 425987919032274, 2207028919301688, 1220490630685848, 974799131293748
+])
 fe25519.curve25519_A = fe25519([486662, 0, 0, 0, 0])
 
 if __name__ == "__main__":
